# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKCommonPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkImageSourcePython
else:
    import _itkImageSourcePython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImagePython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkPointPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkRGBAPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageRegionPython
import itk.ITKCommonBasePython
import itk.itkIndexPython
import itk.itkRGBPixelPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageSourceCommonPython
class itkImageSourceICF2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceICF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageCF2
        GetOutput(self) -> itkImageCF2
        GetOutput(self, idx) -> itkImageCF2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceICF2_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICF2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICF2_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceICF2_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceICF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceICF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceICF2_cast(obj)

# Register itkImageSourceICF2 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceICF2_swigregister(itkImageSourceICF2)
class itkImageSourceICF3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceICF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageCF3
        GetOutput(self) -> itkImageCF3
        GetOutput(self, idx) -> itkImageCF3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceICF3_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICF3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICF3_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceICF3_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceICF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceICF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceICF3_cast(obj)

# Register itkImageSourceICF3 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceICF3_swigregister(itkImageSourceICF3)
class itkImageSourceICVD22(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceICVD22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageCVD22
        GetOutput(self) -> itkImageCVD22
        GetOutput(self, idx) -> itkImageCVD22

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceICVD22_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICVD22_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICVD22_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceICVD22_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceICVD22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceICVD22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceICVD22_cast(obj)

# Register itkImageSourceICVD22 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceICVD22_swigregister(itkImageSourceICVD22)
class itkImageSourceICVD33(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceICVD33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageCVD33
        GetOutput(self) -> itkImageCVD33
        GetOutput(self, idx) -> itkImageCVD33

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceICVD33_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICVD33_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICVD33_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceICVD33_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceICVD33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceICVD33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceICVD33_cast(obj)

# Register itkImageSourceICVD33 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceICVD33_swigregister(itkImageSourceICVD33)
class itkImageSourceICVF22(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceICVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageCVF22
        GetOutput(self) -> itkImageCVF22
        GetOutput(self, idx) -> itkImageCVF22

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceICVF22_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICVF22_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICVF22_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceICVF22_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceICVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceICVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceICVF22_cast(obj)

# Register itkImageSourceICVF22 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceICVF22_swigregister(itkImageSourceICVF22)
class itkImageSourceICVF23(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceICVF23 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageCVF23
        GetOutput(self) -> itkImageCVF23
        GetOutput(self, idx) -> itkImageCVF23

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceICVF23_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICVF23_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICVF23_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceICVF23_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceICVF23

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceICVF23

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceICVF23_cast(obj)

# Register itkImageSourceICVF23 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceICVF23_swigregister(itkImageSourceICVF23)
class itkImageSourceICVF32(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceICVF32 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageCVF32
        GetOutput(self) -> itkImageCVF32
        GetOutput(self, idx) -> itkImageCVF32

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceICVF32_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICVF32_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICVF32_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceICVF32_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceICVF32

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceICVF32

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceICVF32_cast(obj)

# Register itkImageSourceICVF32 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceICVF32_swigregister(itkImageSourceICVF32)
class itkImageSourceICVF33(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceICVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageCVF33
        GetOutput(self) -> itkImageCVF33
        GetOutput(self, idx) -> itkImageCVF33

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceICVF33_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICVF33_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICVF33_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceICVF33_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceICVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceICVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceICVF33_cast(obj)

# Register itkImageSourceICVF33 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceICVF33_swigregister(itkImageSourceICVF33)
class itkImageSourceICVF42(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceICVF42 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageCVF42
        GetOutput(self) -> itkImageCVF42
        GetOutput(self, idx) -> itkImageCVF42

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceICVF42_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICVF42_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICVF42_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceICVF42_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceICVF42

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceICVF42

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceICVF42_cast(obj)

# Register itkImageSourceICVF42 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceICVF42_swigregister(itkImageSourceICVF42)
class itkImageSourceICVF43(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceICVF43 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageCVF43
        GetOutput(self) -> itkImageCVF43
        GetOutput(self, idx) -> itkImageCVF43

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceICVF43_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICVF43_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceICVF43_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceICVF43_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceICVF43

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceICVF43

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceICVF43_cast(obj)

# Register itkImageSourceICVF43 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceICVF43_swigregister(itkImageSourceICVF43)
class itkImageSourceIF2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageF2
        GetOutput(self) -> itkImageF2
        GetOutput(self, idx) -> itkImageF2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIF2_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIF2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIF2_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIF2_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIF2_cast(obj)

# Register itkImageSourceIF2 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIF2_swigregister(itkImageSourceIF2)
class itkImageSourceIF3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageF3
        GetOutput(self) -> itkImageF3
        GetOutput(self, idx) -> itkImageF3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIF3_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIF3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIF3_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIF3_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIF3_cast(obj)

# Register itkImageSourceIF3 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIF3_swigregister(itkImageSourceIF3)
class itkImageSourceIRGBAUC2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIRGBAUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageRGBAUC2
        GetOutput(self) -> itkImageRGBAUC2
        GetOutput(self, idx) -> itkImageRGBAUC2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIRGBAUC2_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIRGBAUC2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIRGBAUC2_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIRGBAUC2_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIRGBAUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIRGBAUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIRGBAUC2_cast(obj)

# Register itkImageSourceIRGBAUC2 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIRGBAUC2_swigregister(itkImageSourceIRGBAUC2)
class itkImageSourceIRGBAUC3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIRGBAUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageRGBAUC3
        GetOutput(self) -> itkImageRGBAUC3
        GetOutput(self, idx) -> itkImageRGBAUC3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIRGBAUC3_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIRGBAUC3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIRGBAUC3_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIRGBAUC3_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIRGBAUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIRGBAUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIRGBAUC3_cast(obj)

# Register itkImageSourceIRGBAUC3 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIRGBAUC3_swigregister(itkImageSourceIRGBAUC3)
class itkImageSourceIRGBUC2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIRGBUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageRGBUC2
        GetOutput(self) -> itkImageRGBUC2
        GetOutput(self, idx) -> itkImageRGBUC2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIRGBUC2_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIRGBUC2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIRGBUC2_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIRGBUC2_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIRGBUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIRGBUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIRGBUC2_cast(obj)

# Register itkImageSourceIRGBUC2 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIRGBUC2_swigregister(itkImageSourceIRGBUC2)
class itkImageSourceIRGBUC3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIRGBUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageRGBUC3
        GetOutput(self) -> itkImageRGBUC3
        GetOutput(self, idx) -> itkImageRGBUC3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIRGBUC3_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIRGBUC3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIRGBUC3_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIRGBUC3_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIRGBUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIRGBUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIRGBUC3_cast(obj)

# Register itkImageSourceIRGBUC3 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIRGBUC3_swigregister(itkImageSourceIRGBUC3)
class itkImageSourceISI2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceISI2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageSI2
        GetOutput(self) -> itkImageSI2
        GetOutput(self, idx) -> itkImageSI2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceISI2_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceISI2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceISI2_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceISI2_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceISI2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceISI2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceISI2_cast(obj)

# Register itkImageSourceISI2 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceISI2_swigregister(itkImageSourceISI2)
class itkImageSourceISI3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceISI3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageSI3
        GetOutput(self) -> itkImageSI3
        GetOutput(self, idx) -> itkImageSI3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceISI3_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceISI3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceISI3_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceISI3_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceISI3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceISI3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceISI3_cast(obj)

# Register itkImageSourceISI3 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceISI3_swigregister(itkImageSourceISI3)
class itkImageSourceISS2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageSS2
        GetOutput(self) -> itkImageSS2
        GetOutput(self, idx) -> itkImageSS2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceISS2_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceISS2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceISS2_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceISS2_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceISS2_cast(obj)

# Register itkImageSourceISS2 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceISS2_swigregister(itkImageSourceISS2)
class itkImageSourceISS3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageSS3
        GetOutput(self) -> itkImageSS3
        GetOutput(self, idx) -> itkImageSS3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceISS3_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceISS3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceISS3_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceISS3_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceISS3_cast(obj)

# Register itkImageSourceISS3 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceISS3_swigregister(itkImageSourceISS3)
class itkImageSourceISSRTD22(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceISSRTD22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageSSRTD22
        GetOutput(self) -> itkImageSSRTD22
        GetOutput(self, idx) -> itkImageSSRTD22

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceISSRTD22_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceISSRTD22_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceISSRTD22_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceISSRTD22_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceISSRTD22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceISSRTD22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceISSRTD22_cast(obj)

# Register itkImageSourceISSRTD22 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceISSRTD22_swigregister(itkImageSourceISSRTD22)
class itkImageSourceISSRTD33(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceISSRTD33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageSSRTD33
        GetOutput(self) -> itkImageSSRTD33
        GetOutput(self, idx) -> itkImageSSRTD33

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceISSRTD33_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceISSRTD33_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceISSRTD33_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceISSRTD33_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceISSRTD33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceISSRTD33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceISSRTD33_cast(obj)

# Register itkImageSourceISSRTD33 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceISSRTD33_swigregister(itkImageSourceISSRTD33)
class itkImageSourceISSRTF22(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceISSRTF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageSSRTF22
        GetOutput(self) -> itkImageSSRTF22
        GetOutput(self, idx) -> itkImageSSRTF22

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceISSRTF22_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceISSRTF22_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceISSRTF22_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceISSRTF22_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceISSRTF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceISSRTF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceISSRTF22_cast(obj)

# Register itkImageSourceISSRTF22 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceISSRTF22_swigregister(itkImageSourceISSRTF22)
class itkImageSourceISSRTF33(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceISSRTF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageSSRTF33
        GetOutput(self) -> itkImageSSRTF33
        GetOutput(self, idx) -> itkImageSSRTF33

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceISSRTF33_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceISSRTF33_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceISSRTF33_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceISSRTF33_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceISSRTF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceISSRTF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceISSRTF33_cast(obj)

# Register itkImageSourceISSRTF33 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceISSRTF33_swigregister(itkImageSourceISSRTF33)
class itkImageSourceIUC2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageUC2
        GetOutput(self) -> itkImageUC2
        GetOutput(self, idx) -> itkImageUC2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIUC2_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIUC2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIUC2_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIUC2_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIUC2_cast(obj)

# Register itkImageSourceIUC2 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIUC2_swigregister(itkImageSourceIUC2)
class itkImageSourceIUC3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageUC3
        GetOutput(self) -> itkImageUC3
        GetOutput(self, idx) -> itkImageUC3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIUC3_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIUC3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIUC3_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIUC3_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIUC3_cast(obj)

# Register itkImageSourceIUC3 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIUC3_swigregister(itkImageSourceIUC3)
class itkImageSourceIUI2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIUI2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageUI2
        GetOutput(self) -> itkImageUI2
        GetOutput(self, idx) -> itkImageUI2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIUI2_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIUI2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIUI2_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIUI2_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIUI2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIUI2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIUI2_cast(obj)

# Register itkImageSourceIUI2 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIUI2_swigregister(itkImageSourceIUI2)
class itkImageSourceIUI3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIUI3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageUI3
        GetOutput(self) -> itkImageUI3
        GetOutput(self, idx) -> itkImageUI3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIUI3_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIUI3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIUI3_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIUI3_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIUI3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIUI3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIUI3_cast(obj)

# Register itkImageSourceIUI3 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIUI3_swigregister(itkImageSourceIUI3)
class itkImageSourceIUL2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIUL2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageUL2
        GetOutput(self) -> itkImageUL2
        GetOutput(self, idx) -> itkImageUL2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIUL2_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIUL2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIUL2_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIUL2_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIUL2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIUL2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIUL2_cast(obj)

# Register itkImageSourceIUL2 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIUL2_swigregister(itkImageSourceIUL2)
class itkImageSourceIUL3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIUL3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageUL3
        GetOutput(self) -> itkImageUL3
        GetOutput(self, idx) -> itkImageUL3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIUL3_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIUL3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIUL3_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIUL3_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIUL3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIUL3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIUL3_cast(obj)

# Register itkImageSourceIUL3 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIUL3_swigregister(itkImageSourceIUL3)
class itkImageSourceIULL2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIULL2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageULL2
        GetOutput(self) -> itkImageULL2
        GetOutput(self, idx) -> itkImageULL2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIULL2_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIULL2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIULL2_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIULL2_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIULL2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIULL2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIULL2_cast(obj)

# Register itkImageSourceIULL2 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIULL2_swigregister(itkImageSourceIULL2)
class itkImageSourceIULL3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIULL3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageULL3
        GetOutput(self) -> itkImageULL3
        GetOutput(self, idx) -> itkImageULL3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIULL3_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIULL3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIULL3_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIULL3_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIULL3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIULL3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIULL3_cast(obj)

# Register itkImageSourceIULL3 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIULL3_swigregister(itkImageSourceIULL3)
class itkImageSourceIVF22(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIVF22 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageVF22
        GetOutput(self) -> itkImageVF22
        GetOutput(self, idx) -> itkImageVF22

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIVF22_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIVF22_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIVF22_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIVF22_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIVF22

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIVF22

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIVF22_cast(obj)

# Register itkImageSourceIVF22 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIVF22_swigregister(itkImageSourceIVF22)
class itkImageSourceIVF23(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIVF23 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageVF23
        GetOutput(self) -> itkImageVF23
        GetOutput(self, idx) -> itkImageVF23

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIVF23_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIVF23_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIVF23_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIVF23_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIVF23

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIVF23

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIVF23_cast(obj)

# Register itkImageSourceIVF23 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIVF23_swigregister(itkImageSourceIVF23)
class itkImageSourceIVF32(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIVF32 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageVF32
        GetOutput(self) -> itkImageVF32
        GetOutput(self, idx) -> itkImageVF32

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIVF32_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIVF32_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIVF32_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIVF32_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIVF32

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIVF32

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIVF32_cast(obj)

# Register itkImageSourceIVF32 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIVF32_swigregister(itkImageSourceIVF32)
class itkImageSourceIVF33(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIVF33 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageVF33
        GetOutput(self) -> itkImageVF33
        GetOutput(self, idx) -> itkImageVF33

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIVF33_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIVF33_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIVF33_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIVF33_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIVF33

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIVF33

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIVF33_cast(obj)

# Register itkImageSourceIVF33 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIVF33_swigregister(itkImageSourceIVF33)
class itkImageSourceIVF42(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIVF42 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageVF42
        GetOutput(self) -> itkImageVF42
        GetOutput(self, idx) -> itkImageVF42

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIVF42_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIVF42_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIVF42_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIVF42_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIVF42

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIVF42

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIVF42_cast(obj)

# Register itkImageSourceIVF42 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIVF42_swigregister(itkImageSourceIVF42)
class itkImageSourceIVF43(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceIVF43 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkImageVF43
        GetOutput(self) -> itkImageVF43
        GetOutput(self, idx) -> itkImageVF43

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceIVF43_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIVF43_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceIVF43_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceIVF43_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceIVF43

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceIVF43

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceIVF43_cast(obj)

# Register itkImageSourceIVF43 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceIVF43_swigregister(itkImageSourceIVF43)
class itkImageSourcePA3DSCICF(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourcePA3DSCICF class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkPhasedArray3DSpecialCoordinatesImageCF
        GetOutput(self) -> itkPhasedArray3DSpecialCoordinatesImageCF
        GetOutput(self, idx) -> itkPhasedArray3DSpecialCoordinatesImageCF

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCICF_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCICF_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCICF_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCICF_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourcePA3DSCICF

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourcePA3DSCICF

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCICF_cast(obj)

# Register itkImageSourcePA3DSCICF in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourcePA3DSCICF_swigregister(itkImageSourcePA3DSCICF)
class itkImageSourcePA3DSCIF(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourcePA3DSCIF class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkPhasedArray3DSpecialCoordinatesImageF
        GetOutput(self) -> itkPhasedArray3DSpecialCoordinatesImageF
        GetOutput(self, idx) -> itkPhasedArray3DSpecialCoordinatesImageF

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCIF_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCIF_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCIF_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCIF_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourcePA3DSCIF

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourcePA3DSCIF

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCIF_cast(obj)

# Register itkImageSourcePA3DSCIF in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourcePA3DSCIF_swigregister(itkImageSourcePA3DSCIF)
class itkImageSourcePA3DSCISS(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourcePA3DSCISS class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkPhasedArray3DSpecialCoordinatesImageSS
        GetOutput(self) -> itkPhasedArray3DSpecialCoordinatesImageSS
        GetOutput(self, idx) -> itkPhasedArray3DSpecialCoordinatesImageSS

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCISS_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCISS_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCISS_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCISS_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourcePA3DSCISS

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourcePA3DSCISS

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCISS_cast(obj)

# Register itkImageSourcePA3DSCISS in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourcePA3DSCISS_swigregister(itkImageSourcePA3DSCISS)
class itkImageSourcePA3DSCIUC(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourcePA3DSCIUC class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkPhasedArray3DSpecialCoordinatesImageUC
        GetOutput(self) -> itkPhasedArray3DSpecialCoordinatesImageUC
        GetOutput(self, idx) -> itkPhasedArray3DSpecialCoordinatesImageUC

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCIUC_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCIUC_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCIUC_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCIUC_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourcePA3DSCIUC

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourcePA3DSCIUC

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourcePA3DSCIUC_cast(obj)

# Register itkImageSourcePA3DSCIUC in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourcePA3DSCIUC_swigregister(itkImageSourcePA3DSCIUC)
class itkImageSourceVIF2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceVIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkVectorImageF2
        GetOutput(self) -> itkVectorImageF2
        GetOutput(self, idx) -> itkVectorImageF2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceVIF2_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceVIF2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceVIF2_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceVIF2_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceVIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceVIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceVIF2_cast(obj)

# Register itkImageSourceVIF2 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceVIF2_swigregister(itkImageSourceVIF2)
class itkImageSourceVIF3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceVIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkVectorImageF3
        GetOutput(self) -> itkVectorImageF3
        GetOutput(self, idx) -> itkVectorImageF3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceVIF3_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceVIF3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceVIF3_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceVIF3_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceVIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceVIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceVIF3_cast(obj)

# Register itkImageSourceVIF3 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceVIF3_swigregister(itkImageSourceVIF3)
class itkImageSourceVISS2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceVISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkVectorImageSS2
        GetOutput(self) -> itkVectorImageSS2
        GetOutput(self, idx) -> itkVectorImageSS2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceVISS2_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceVISS2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceVISS2_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceVISS2_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceVISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceVISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceVISS2_cast(obj)

# Register itkImageSourceVISS2 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceVISS2_swigregister(itkImageSourceVISS2)
class itkImageSourceVISS3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceVISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkVectorImageSS3
        GetOutput(self) -> itkVectorImageSS3
        GetOutput(self, idx) -> itkVectorImageSS3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceVISS3_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceVISS3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceVISS3_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceVISS3_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceVISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceVISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceVISS3_cast(obj)

# Register itkImageSourceVISS3 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceVISS3_swigregister(itkImageSourceVISS3)
class itkImageSourceVIUC2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceVIUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkVectorImageUC2
        GetOutput(self) -> itkVectorImageUC2
        GetOutput(self, idx) -> itkVectorImageUC2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceVIUC2_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceVIUC2_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceVIUC2_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceVIUC2_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceVIUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceVIUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceVIUC2_cast(obj)

# Register itkImageSourceVIUC2 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceVIUC2_swigregister(itkImageSourceVIUC2)
class itkImageSourceVIUC3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkImageSourceVIUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkVectorImageUC3
        GetOutput(self) -> itkVectorImageUC3
        GetOutput(self, idx) -> itkVectorImageUC3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkImageSourcePython.itkImageSourceVIUC3_GetOutput(self, *args)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceVIUC3_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkImageSourcePython.itkImageSourceVIUC3_GraftNthOutput(self, idx, graft)

    def MakeOutput(self, *args):
        r"""
        MakeOutput(self, idx) -> itkDataObject_Pointer

        Parameters
        ----------
        idx: unsigned long

        MakeOutput(self, arg0) -> itkDataObject_Pointer

        Parameters
        ----------
        arg0: std::string const &

        """
        return _itkImageSourcePython.itkImageSourceVIUC3_MakeOutput(self, *args)
    __swig_destroy__ = _itkImageSourcePython.delete_itkImageSourceVIUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkImageSourceVIUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkImageSourcePython.itkImageSourceVIUC3_cast(obj)

# Register itkImageSourceVIUC3 in _itkImageSourcePython:
_itkImageSourcePython.itkImageSourceVIUC3_swigregister(itkImageSourceVIUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def image_source(*args, **kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for ImageSource"""
    import itk

    kwarg_typehints = {  }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ImageSource.New(*args, **kwargs)

    return instance.__internal_call__()

def image_source_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKCommon.ImageSource
    image_source.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    image_source.__doc__ = filter_object.__doc__



